@@ -86,7 +86,7 @@ from types import GeneratorType, ModuleType, FunctionType, BuiltinFunctionType
 from collections import deque
 from binascii import a2b_hex, b2a_hex
 
-VERSION = '0.18'
+VERSION = '0.18.1'
 MIN_COMPAT_VERSION = '0.16'
 
 PYTHON3 = sys.version_info >= (3, 0)
@@ -1955,7 +1955,7 @@ def parse_connection_spec(spec, default_port=DEFAULT_PORT, default_key=b'',
         raise ValueError(str(e) + ' (in connection spec %r)' % spec)
 
     params.update(new_params)
-    print(params)
+
     if custom_options:
         return params, custom
     else:
