@@ -97,7 +97,6 @@ def _get_global_root(mod, attr):
 
 def _try_import(mod, name, is_root):
     newname = (name if is_root else mod.__name__ + '.' + name)
-
     try:
         newmod = __import__(newname)
     except ImportError:
@@ -196,6 +195,22 @@ class RootObject(object):
         for n in names:
             setattr(self._defmod, n, __import__(n))
         
+def profile_request(func, args):
+    '''Profile a function call and write the results to the user's
+    home directory. Used only for debugging.'''
+    import cProfile, pstats
+    ctime = time.time()
+    itime = int(ctime)
+    frac = ctime - itime
+    strtime = time.strftime('%Y_%m_%d_%H_%M_%S', time.localtime(itime)) + '.%08d' % int(frac * 10000000)
+    fn = 'profile_%s.txt' % strtime
+    prof = cProfile.Profile()
+    prof.runcall(func, *args)
+    
+    with open(os.path.join(os.getenv('HOME'), fn), 'w') as fp:
+        fp.write('Profile of %r:\n' % (args,))
+        pstats.Stats(prof, stream=fp).sort_stats('time').print_stats()
+
 class ServerThread(threading.Thread):
     '''A thread that runs code on behalf of the client.'''
     def __init__(self, svr, tid):
@@ -216,6 +231,7 @@ class ServerThread(threading.Thread):
             rid, obj, meth, args, kw = queue.get()
             if obj is None:
                 return
+            #profile_request(svr.run_request, (rid, obj, meth, args, kw))
             svr.run_request(rid, obj, meth, args, kw)
 
 class Server(_core.Connection):
@@ -225,7 +241,7 @@ class Server(_core.Connection):
     _recviv = b'CLNT'
 
     def __init__(self, key, sock, peername):
-        _core.Connection.__init__(self, key)
+        _core.Connection.__init__(self, key, True)
         self._next_object_id = 1
         self._next_type_id = 1
 
@@ -363,7 +379,7 @@ class Server(_core.Connection):
         if typedat is None:
             return None
 
-        tid = self._local_id_by_typedat.get(typ)
+        tid = self._local_id_by_typedat.get(typedat)
         oid = self._next_object_id
         self._next_object_id = oid + 1
         self._local_id_by_object[id(obj)] = oid
