@@ -16,9 +16,6 @@ from __future__ import print_function
 
 import time
 class TestObject(ServerObject):
-    #export_methods = 'setval', 'getval'
-    #export_attrs = 'val',
-
     def __init__(self, name, val):
         self.name = name
         self.val = val
@@ -87,6 +84,26 @@ class TestObject3(ServerObject):
         print('Testobject __add__: %s + %s = %s' % (self.val, oval, rval))
         return TestObject3(rval)
 
+class TestDefaultProxy(DefaultRemoteProxy):
+    pass
+
+class TestObject4(ServerObject):
+    proxy_class = TestDefaultProxy
+
+    def __init__(self, a):
+        self.a = a
+
+    def instmethod(self):
+        return self.a
+
+    @classmethod
+    def cmethod(cls):
+        return cls.__name__
+
+    @staticmethod
+    def smethod():
+        return 'static'
+
 testobjects = [TestObject('s%d' % i, i) for i in range(3)]
 
 def test_generator_func():
@@ -166,7 +183,7 @@ def exceptions():
         ## Have the object throw a RemoteException instead of
         ## the original exception. This will not print the
         ## trace
-        l1.te2(3, nonblocking=True).wait(origexc=False)
+        l1.te2(3, origexc=False)
     except easycluster.RemoteException as e:
         print('Remote exception, traceback:', file=sys.stderr)
         print(''.join(e.text), file=sys.stderr)
@@ -185,6 +202,9 @@ def reftest():
     for a, b in zip(objects, otherobjects):
         assert a is b, 'proxy objects are not the same'
 
+    for a in objects:
+        assert type(a) is type(objects[0])
+
     print('Server-created object values: %r' % [o.getval() for o in objects])
 
 @define_test('Test method calls')
@@ -206,8 +226,18 @@ def attrs():
     print('test attr access: obj1.val = %d' % obj1.val)
     obj1.val = 150
     print('obj1.getval() = %d' % obj1.getval())
-
-
+    obj1.newval = 1234
+    obj1.raw_set_attribute('newval2', 9999)
+    d = obj1.raw_get_attribute('__dict__')
+    print('remote __dict__ = %r' % d)
+    assert d.get('newval') == 1234
+    assert d.get('newval2') == 9999
+    del obj1.newval
+    d = obj1.raw_get_attribute('__dict__')
+    print('remote __dict__ = %r' % d)
+    assert 'newval' not in d
+    assert d.get('newval2') == 9999
+    
 @define_test('Test operator overloading (via exported methods)')
 def overload():
     a = l1.TestObject2(3)
@@ -224,10 +254,25 @@ def test_cache():
 
 @define_test('Test custom proxy classes')
 def custom_proxy():
+    from easycluster.remote_code import TestObject3Proxy
     a = l1.TestObject3(3)
     print('proxy class = %r' % type(a))
+    assert isinstance(a, TestObject3Proxy)
     a.lmethod()
 
+@define_test('Test default proxy class')
+def custom_proxy():
+    a = l1.TestObject4(123)
+    assert a.instmethod() == 123
+    assert a.a == 123
+    a.a = 1234
+    assert a.instmethod() == 1234
+    assert a.a == 1234
+    assert a.raw_get_attribute('__dict__')['a'] == 1234
+
+    assert a.cmethod() == 'TestObject4'
+    assert a.smethod() == 'static'
+
 @define_test('Test old-style classes')
 def old():
     obj1 = l1.TestOldStyleClass(300)
